@@ -1,10 +1,11 @@
 import json
-from collections.abc import MutableMapping, MutableSequence
+from collections.abc import Iterable, MutableMapping, MutableSequence
 from http import HTTPStatus
 from logging import Logger, getLogger
 from time import time
 from typing import Any, Literal, TypeAlias, cast
 
+from starlette import status
 from starlette.middleware.base import BaseHTTPMiddleware, DispatchFunction, RequestResponseEndpoint
 from starlette.requests import Request
 from starlette.responses import Response, StreamingResponse
@@ -22,12 +23,12 @@ _Params: TypeAlias = dict[str, Any] | None
 
 
 class LoggingMiddleware(BaseHTTPMiddleware):
-    __slots__: tuple[str, ...] = ("_app_name", "_prefix", "_logger")
-
     _app_name: str
     _prefix: str | None
     _config: LogConfigure | None
     _logger: Logger
+    _exclude_requests_starting_with: frozenset[str]
+    _marker_filtered: str
 
     def __init__(
         self,
@@ -36,10 +37,14 @@ class LoggingMiddleware(BaseHTTPMiddleware):
         dispatch: DispatchFunction | None = None,
         prefix: str | None = None,
         logger: Logger | None = None,
+        exclude_requests_starting_with: Iterable[str] | None = None,
+        marker_filtered: str = "[filtered]",
     ) -> None:
         super(LoggingMiddleware, self).__init__(app, dispatch)
         self._app_name = app_name
         self._prefix = prefix
+        self._exclude_requests_starting_with = frozenset(exclude_requests_starting_with or ())
+        self._marker_filtered = marker_filtered
         if logger is None:
             self._config = init_logger(app_name=app_name)
             self._logger = getLogger("default")
@@ -131,67 +136,68 @@ class LoggingMiddleware(BaseHTTPMiddleware):
                 headers=dict(response.headers),
                 media_type=response.media_type,
             )
-        duration: int = round((time() - start_time) * 1000)
 
-        response_log_payload: ResponsePayload = {
-            "status": response.status_code,
-            "response_time": f"{duration}ms",
-            "response_body": response_body.decode(),
-        }
-        extra_payload = common_extras | {
-            "tags": ["API", "RESPONSE"],
-            "payload": self._filter_private_data(response_log_payload),
-        }
-        self._logger.info(f"RESPONSE {response.status_code} {request.url.path}", extra=extra_payload)
+        if response.status_code >= status.HTTP_400_BAD_REQUEST or not self._is_url_path_in_exclude_list(request):
+            duration: int = round((time() - start_time) * 1000.0)
+            response_log_payload: ResponsePayload = {
+                "status": response.status_code,
+                "response_time": f"{duration}ms",
+                "response_body": response_body.decode(),
+            }
+            extra_payload = common_extras | {
+                "tags": ["API", "RESPONSE"],
+                "payload": self._filter_private_data(response_log_payload),
+            }
+            self._logger.info(f"RESPONSE {response.status_code} {request.url.path}", extra=extra_payload)
+
         return response
 
-    def _filter_private_data(self, payload: _Payload, *, marker_filtered: str = "[filtered]") -> _Payload:
+    def _is_url_path_in_exclude_list(self, request: Request) -> bool:
+        return any(request.url.path.startswith(path) for path in self._exclude_requests_starting_with)
+
+    def _filter_private_data(self, payload: _Payload) -> _Payload:
         if not (filtered_fields := LogConfigure.get_exclude_fields(self._config)):
             return payload
 
         match payload:
             case {"method": _, "path": _, "host": _, "params": params, "body": str(body)} as value:
                 payload = cast(RequestPayload, value)
-                payload["params"] = self._filter_params(
-                    cast(_Params, params),
-                    filtered_fields,
-                    marker_filtered=marker_filtered,
-                )
-                payload["body"] = self._filter_body(body, filtered_fields, marker_filtered=marker_filtered)
+                payload["params"] = self._filter_params(cast(_Params, params), filtered_fields)
+                payload["body"] = self._filter_body(body, filtered_fields)
             case {"status": _, "response_time": _, "response_body": str(body)} as value:
                 payload = cast(ResponsePayload, value)
-                payload["response_body"] = self._filter_body(body, filtered_fields, marker_filtered=marker_filtered)
+                payload["response_body"] = self._filter_body(body, filtered_fields)
 
         return payload
 
-    def _filter_params(self, params: _Params, filtered_fields: list[str], *, marker_filtered: str) -> _Params:
+    def _filter_params(self, params: _Params, filtered_fields: list[str]) -> _Params:
         if not params or not filtered_fields:
             return params
 
         new_params: dict[str, Any] = params.copy()
         for key in params:
             if key in filtered_fields:
-                new_params[key] = marker_filtered
+                new_params[key] = self._marker_filtered
 
         return new_params
 
-    def _filter_body(self, body: str, filtered_fields: list[str], *, marker_filtered: str) -> str:
+    def _filter_body(self, body: str, filtered_fields: list[str]) -> str:
         try:
             request_json: Any = json.loads(body)
-            response_json: Any = self._filter_json_body(request_json, filtered_fields, marker_filtered=marker_filtered)
+            response_json: Any = self._filter_json_body(request_json, filtered_fields)
             return json.dumps(response_json, ensure_ascii=False, separators=(",", ":"))
         except Exception:
             return body
 
-    def _filter_json_body(self, body: Any, filtered_fields: list[str], *, marker_filtered: str) -> Any:
+    def _filter_json_body(self, body: Any, filtered_fields: list[str]) -> Any:
         if isinstance(body, MutableMapping):
             return {
-                key: self._filter_json_body(value, filtered_fields, marker_filtered=marker_filtered)
+                key: self._filter_json_body(value, filtered_fields)
                 if key not in filtered_fields
-                else marker_filtered
+                else self._marker_filtered
                 for key, value in body.items()
             }
         elif isinstance(body, MutableSequence):
-            return [self._filter_json_body(item, filtered_fields, marker_filtered=marker_filtered) for item in body]
+            return [self._filter_json_body(item, filtered_fields) for item in body]
         else:
             return body
